@@ -39,8 +39,13 @@ def _parse_input_model_name(ctx, param, value):
               required=False, default=None, type=str,
               callback=_parse_input_model_name,
               help='Model name (must be unique in project)')
+@click.option('--cluster/--no-cluster', default=True,
+              help=(
+                  'Whether or not to attach a Compute Cluster '
+                  'to this model after creation'
+              ))
 @click.pass_context
-def init_model(ctx, name, project):
+def init_model(ctx, name, cluster, project):
     """
     Create a new, empty machine learning model.
     \f
@@ -50,6 +55,7 @@ def init_model(ctx, name, project):
 
     :param click.Context ctx:
     :param str name:
+    :param bool cluster:
     :param Project project:
     """
 
@@ -98,9 +104,10 @@ def init_model(ctx, name, project):
 
     # -- Compute cluster -----------------------------------------------------
 
-    create_compute_cluster = click.confirm(
-        text='Would you like to configure a compute cluster for your model?',
-    )
+    if cluster is None:
+        cluster = click.confirm(
+            text='Would you like to configure a compute cluster for your model?',
+        )
 
-    if create_compute_cluster:
+    if cluster:
         ctx.invoke(create_cluster, model=model)
